tests.models.managers package — django_analyses 0.0.3 documentation

# tests.models.managers package

## Submodules

## tests.models.managers.fixtures module

## tests.models.managers.test_analysis_manager module

class `tests.models.managers.test_analysis_manager.` `AnalysisManagerTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `AnalysisManager` class.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_from_dict_with_versions`()
  `test_from_dict_without_versions`()
  `test_from_list`()
  `test_from_list_with_existing_analysis`()

## tests.models.managers.test_run_manager module

## Module contents